import { useRef, useState } from "react";
import dicomParser from "dicom-parser";
import vtkVolume from '@kitware/vtk.js/Rendering/Core/Volume';
import vtkVolumeMapper from '@kitware/vtk.js/Rendering/Core/VolumeMapper';
import vtkFullScreenRenderWindow from '@kitware/vtk.js/Rendering/Misc/FullScreenRenderWindow';
import readImageDICOMFileSeries from "itk/readImageDICOMFileSeries";
import vtkITKHelper from '@kitware/vtk.js/Common/DataModel/ITKHelper';


interface LocalMprProps {
  children?: JSX.Element;
}

export const LocalMpr = (props: LocalMprProps) => {
  const containerRef = useRef(null);
  const handleFolderUpload = async (
    event: React.ChangeEvent<HTMLInputElement>
  ) => {
    if (event.target.files) {
      const files = event.target.files;
      const volumeImageData = await readImageDICOMFileSeries(files);
      const vtkImage = vtkITKHelper.convertItkToVtkImage(volumeImageData);
      const volume = vtkVolume.newInstance();
      const mapper = vtkVolumeMapper.newInstance();
      mapper.setInputData(vtkImage);
      volume.setMapper(mapper);

      // 创建 vtk 的全屏渲染窗口
      const fullScreenRenderer = vtkFullScreenRenderWindow.newInstance({
        background: [0, 0, 0],
        container: containerRef.current!,
      });
      const renderer = fullScreenRenderer.getRenderer();
      const renderWindow = fullScreenRenderer.getRenderWindow();

      // 将 volume 添加到渲染器
      renderer.addVolume(volume);
      // 设置相机位置等
      renderer.resetCamera();
      renderWindow.render();
    }
  };

  return (
    <div>
      <div>
        <input
          type="file"
          webkitdirectory="true"
          directory=""
          onChange={handleFolderUpload}
        />
      </div>
      <div style={{ width: 400, height: 400 }} ref={containerRef}></div>
    </div>
  );
};
